/**
*   WYSIWYG_Editor
*   autor  Justin Koivisto
*   justin.koivisto@gmail.com
*   http://koivi.com
*   editor-es1er.js 
*   modify Paun Es Durlic, 23-31. avgust 2011.
*   @param  instance_name   string  the name of the variable you assigned to this instance ( example: myEdt = new WYSIWYG_Editor('myEdt'); )
*                                   also used as the basis for the name and id attributes for this editor instance in the HTML (hidden input and iframe)
*   @param  content         string  a string of the content to display in the editor.
*   @param  path            string  the URI path to this directory to use for editor components (pallete, iamges, etc.)
*   @param  fwidth          int     the width in pixels of the editor interface on the screen
*   @param  fheight         int     the height in pixels of the editor interface on the screen
*   @param  styleHref       string  the URI of the stylesheet to use for the editor's content window
**/

function WYSIWYG_Editor(instance_name, content, path, fwidth, fheight, styleHref){

    // the name used to create the object - used to define the name of the field that contains the HTML on submission
    if(typeof(instance_name)=='undefined'){
        alert("ERROR: No instance name was passed for the editor.");
        return false;
    }else{
        this.instance_name=instance_name;
    }
    // the initial HTML source content for the editor
    if(typeof(content)=='undefined'){
        this.content='';
    }else{
        this.content=content;
    }
    // define the path to uctse for the editor components like images
    if(typeof(path)=='undefined'){
        this.wysiwyg_path='.'; // default value
    }else{
        path.replace(/[\/\\]$/,''); // remove trailing slashes
        this.wysiwyg_path=path;
    }
    // define the pixel dimensions of the editor
    if(typeof(fwidth)=='number' && Math.round(fwidth) > 50){
        this.frame_width=Math.round(fwidth); // default value
    }else{
        this.frame_width=700; // default width било 548
    }
    if(typeof(fheight)=='number' && Math.round(fheight) > 50){
        this.frame_height=Math.round(fheight);
    }else{
        this.frame_height=300; // default height било 250
    }
    // define the stylesheet to use for the editor components like images
    if(typeof(styleHref)=='undefined'){
        this.stylesheet=''; // default value

    }else{
        this.stylesheet=styleHref;
    }
 
    // properties that depended on the validated values above
    this.wysiwyg_content=this.instance_name+'_WYSIWYG_Editor';  // the editor IFRMAE element id
    this.wysiwyg_hidden=this.instance_name+'_content';          // the editor's hidden field to store the HTML in for the post
    //this.wysiwyg_speller=this.instance_name+'_speller';       // the editor's hidden textarea to store the HTML in for the spellchecker
    this.ta_rows=Math.round(this.frame_height/15);              // number of rows for textarea for unsupported browsers
    this.ta_cols=Math.round(this.frame_width/8);                // number of cols for textarea for unsupported browsers

    // other property defaults
    this.viewMode=1;                                        // by default, set to design view
    this._X = this._Y = 0;                                  // these are used to determine mouse position when clicked

     // insert table defaults
    this.table_border = 1;                                  // default border used when inserting tables
    this.table_cell_padding = 1;                            // default cellpadding used when inserting tables
    this.table_cell_spacing = 0;                            // default cellspacing used when inserting tables

     // stavke sa liste sklonio Paun
    this.allow_mode_toggle = true;                          // allow users to switch to source code mode
    this.font_format_toolbar1 = true;                       // selekt lista - gramatika 
    this.font_format_toolbar3 = true;                       // buttons for bold, italic, underline
    this.font_format_toolbar4 = true;                       // buttons for superscript, subscript
    this.alignment_toolbar1 = true;                         // buttons for left, center, right, full justify
    this.alignment_toolbar2 = true;                         // buttons for indent, outdent
 
    this.web_toolbar1 = true;                               // buttons for add, remove hyperlinks
    this.web_toolbar2 = true;                               // buttons for ordered, unordered lists
    this.web_toolbar3 = true;                               // buttons for horizontal rule, insert table
    this.web_toolbar4 = true;                               // buttons for insert image and save (submit form)
    this.misc_format_toolbar = true;                       // buttons for remove format, copy, paste, redo, undo, etc.

    // this makes a save icon that submits the form in web_toolbar4
    //this.save_button = true;
    // what kind of separator to use after each toolbar
    // "br" is a line break, "|" is an image separator, false is nothing
    this.font_format_toolbar1_after = false;
    this.font_format_toolbar2_after = '|';
    this.font_format_toolbar3_after = '|';
    
     //this.font_format_toolbar4_after = 'br';
    this.alignment_toolbar1_after = '|';
    this.alignment_toolbar2_after = '|';
    this.web_toolbar1_after = '|';
    this.web_toolbar2_after = '|';
    this.web_toolbar3_after = false;
    this.web_toolbar4_after = false;
    this.misc_format_toolbar_after = false;

    this.site_path = this.wysiwyg_path;                     // default to what was passed, should be set in HTML
    this.page_title = 'index';                              // default to nothing, should be set in HTML
}

/**
*   WYSIWYG_Editor::prepareSubmit
*   Use this in the onSubmit event for the form that the editor is displayed inside.
**/
WYSIWYG_Editor.prototype.prepareSubmit = function (){
    if(this.viewMode == 2){
        // be sure this is in design view before submission
        this.toggleMode();
    }
    var htmlCode=document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML;
    document.getElementById(this.wysiwyg_hidden).value=htmlCode;
    return true;
}

/**
*   WYSIWYG_Editor::display
*   Display the editor interface for the user
**/
WYSIWYG_Editor.prototype.display = function (){
    if(this.isSupported()){
        this._display_editor();
        this._load_content();
        var thedoc = document.getElementById(this.wysiwyg_content).contentWindow.document;
        thedoc.designMode='On';
        // MSIE has caching problems...
        // http://technet2.microsoft.com/WindowsServer/en/Library/8e06b837-0027-4f47-95d6-0a60579904bc1033.mspx
        thedoc = document.getElementById(this.wysiwyg_content).contentWindow.document;
        thedoc.open();
		/*******************
		* ovde je jedino mesto gde editor reaguje na kombinacije Alt+slovo
		* dodatak sa focusom ubacuje kursor u polje editora posel refresa strane
		* a ovaj focus() opmogucava da se kuros vidi u cosku editora
		************/
		document.getElementById(this.wysiwyg_content).contentWindow.focus();
		thedoc.onkeydown = Makroi;
        /*******
		* end
		*************/		
        thedoc.write('<html><head>');
        if(this.stylesheet){
            // must be done after the document has been opened
            thedoc.write('<style type="text/css">@import url('+this.stylesheet+');</style>');
        }
        thedoc.write('</head><body>');
        thedoc.write(this.content);
        thedoc.write('</body></html>');
        thedoc.close();
    }else{
        this._display_textarea();
        this._load_content();
    }
}

/**
*   WYSIWYG_Editor::_display_textarea
*   Nepodrzani pregledaci
**/
WYSIWYG_Editor.prototype._display_textarea = function (){
    document.write('<p style="background-color: yellow; color: red; padding: 3px;"><b>WARNING:</b> Your browser does not support the WYSIWYG_Editor class. The script you are posting to may expect HTML code.</p>');
    document.write('<textarea name="'+this.wysiwyg_hidden+'" id="'+this.wysiwyg_hidden+'" rows="'+this.ta_rows+'" cols="'+this.ta_cols+'"></textarea><br>');
}

/**
*   WYSIWYG_Editor::_display_editor
*   Used to display the actual wysiwyg editor HTML interface to supported browsers
**/
WYSIWYG_Editor.prototype._display_editor = function (){
  
    document.write('   <textarea name="'+this.wysiwyg_hidden+'" id="'+this.wysiwyg_hidden+'"  style="visibility:hidden;display:none;"></textarea>'); 
    //document.write('   <textarea name="'+this.wysiwyg_hidden+'" id="'+this.wysiwyg_hidden+'"  style="visibility:visible;display:on;width:100%;"></textarea>'); 	
    document.write('   <table cellpadding="5" cellspacing="0" border="2" id="'+this.instance_name+'_table" bgcolor="#dfdfdf">');
    document.write('    <tr>');
    document.write('     <td>');
    document.write('      <table width="100%" border="0" cellspacing="0" cellpadding="0">');
    document.write('       <tr>');
    document.write('        <td valign="top" colspan="2">');
    document.write('         <div id="'+this.instance_name+'_toolbars">');
    
   // paunov dodatak
    if(this.alignment_toolbar1){
        //velika slova
        document.write('          <img alt="MUKLO_A" title="MUKLO_A" class="butClass" src="'+this.wysiwyg_path+'/vlcod/a1_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ă\') ">');
        document.write('          <img alt="MUKLO_A2" title="MUKLO_A2" class="butClass" src="'+this.wysiwyg_path+'/vlcod/a2_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Â\',\'\')">');
        document.write('          <img alt="DZ" title="DZ_AFRIKATA" class="butClass" src="'+this.wysiwyg_path+'/vlcod/dz_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ḑ\',\'\')">');
        document.write('          <img alt="DŽ" title="DŽ" class="butClass" src="'+this.wysiwyg_path+'/vlcod/dg_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ğ\',\'\')">');       
        document.write('          <img alt="MUKLO_I" title="MUKLO_I" class="butClass" src="'+this.wysiwyg_path+'/vlcod/i_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Î\',\'\')">');        
        document.write('          <img alt="J" title="J" class="butClass" src="'+this.wysiwyg_path+'/vlcod/j_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ĭ\',\'\')">');
        document.write('          <img alt="LJ" title="LJ" class="butClass" src="'+this.wysiwyg_path+'/vlcod/l2_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ļ\',\'\')">');        
        document.write('          <img alt="NJ" title="NJ" class="butClass" src="'+this.wysiwyg_path+'/vlcod/n_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ń\',\'\')">');        
        document.write('          <img alt="SJ" title="SJ" class="butClass" src="'+this.wysiwyg_path+'/vlcod/s_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ś\',\'\')">');        
        document.write('          <img alt="ZJ" title="ZJ" class="butClass" src="'+this.wysiwyg_path+'/vlcod/z_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ź\',\'\')">');             
        document.write('          <img alt="C" title="C" class="butClass" src="'+this.wysiwyg_path+'/vlcod/t_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ț\',\'\')">');
        document.write('          <img alt="TJ" title="TJ" class="butClass" src="'+this.wysiwyg_path+'/vlcod/tj_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ť\',\'\')">');
        document.write('          <img alt="GJ" title="GJ" class="butClass" src="'+this.wysiwyg_path+'/vlcod/gj_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ď\',\'\')">');
        document.write('          <img alt="SH" title="Š" class="butClass" src="'+this.wysiwyg_path+'/vlcod/sh_veliko.gif" onClick="'+this.instance_name+'.insertMyText(\'Ș\',\'\')">');
        
        document.write('          <img alt="„" title="Navodnik levi" class="butClass" src="'+this.wysiwyg_path+'/vlcod/nav_d.gif" onClick="'+this.instance_name+'.insertMyText(\'„\',\'\')">');     
        document.write('          <img alt="”" title="Navodnik desni" class="butClass" src="'+this.wysiwyg_path+'/vlcod/nav_g.gif" onClick="'+this.instance_name+'.insertMyText(\'”\',\'\')">');
        document.write('          <img alt="Romb" title="Romb" class="butClass" src="'+this.wysiwyg_path+'/vlcod/romb.gif" onClick="'+this.instance_name+'.insertMyText(\' ◊ \',\'\')">');
        
        document.write('          <img alt="Romb crni" title="Romb crni" class="butClass" src="'+this.wysiwyg_path+'/vlcod/rombcrni.gif" onClick="'+this.instance_name+'.insertMyText(\' ♦ ##\',\'\')">');        
        document.write('          <img alt="Romb crni" title="Romb upor" class="butClass" src="'+this.wysiwyg_path+'/vlcod/rombcrni.gif" onClick="'+this.instance_name+'.insertMyText(\' ♦ up. ##\',\'\')">');            
        document.write('          <img alt="Poveznica" title="Poveznica" class="butClass" src="'+this.wysiwyg_path+'/vlcod/poveznica.gif" onClick="'+this.instance_name+'.insertMyTextLIN(\' ∞ ##\',\'\')">');
        document.write('          <img id="mlin" alt="Linija" title="Linija" class="butClass" src="'+this.wysiwyg_path+'/vlcod/duzalinija.gif" onClick="'+this.instance_name+'.insertMyTextLIN(\' — **\',\'\')">');
        document.write('          <img alt="ozvezdi" title="ozvezdi" class="butClass" src="'+this.wysiwyg_path+'/vlcod/ozvezdi.gif" onClick="'+this.instance_name+'.insertMyText(\' ** \')">');
        document.write('          <img alt="boldiraj" title="boldiraj" class="butClass" src="'+this.wysiwyg_path+'/vlcod/tarabuj.gif" onClick="'+this.instance_name+'.insertMyTextLIN(\' ##\')">');
        document.write('          <img alt="italikovanje" title="italikuj" class="butClass" src="'+this.wysiwyg_path+'/vlcod/italikuj.gif" onClick="'+this.instance_name+'.Italikuj(\'\')">');       

        document.write('          <img alt="boldubaci" id="boldp" title="boldubaci" class="butClass" src="'+this.wysiwyg_path+'/vlcod/boldp.png" onClick="'+this.instance_name+'.insertMyTextBOLD(\'\<b>\',\'\')">');       

 
       document.write('         <br>');

        //mala slova m+
        document.write('          <img id="ma" alt="mukla_a" title="mukla_a" class="butClass" src="'+this.wysiwyg_path+'/vlcod/a1_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'ă\',\'\')">');
        document.write('          <img id="mf" alt="muklo_a2" title="mukla_a2" class="butClass" src="'+this.wysiwyg_path+'/vlcod/a2_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'â\',\'\')">');
        document.write('          <img id="mdz" alt="dz" title="alt+g" class="butClass" src="'+this.wysiwyg_path+'/vlcod/dz_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'ḑ\',\'\')">');
        document.write('          <img id="mg" alt="dž" title="dž" class="butClass" src="'+this.wysiwyg_path+'/vlcod/dg_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'ğ\',\'\')">');
        document.write('          <img id="mi" alt="muklo_i" title="muklo_i" class="butClass" src="'+this.wysiwyg_path+'/vlcod/i_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'&icirc;\',\'\')">');
        document.write('          <img id="mj" alt="j" title="j" class="butClass" src="'+this.wysiwyg_path+'/vlcod/j_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'&#301;\',\'\')">');        
        document.write('          <img id="ml" alt="lj" title="lj" class="butClass" src="'+this.wysiwyg_path+'/vlcod/l2_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'ļ\',\'\')">');
        document.write('          <img id="mn" alt="nj" title="nj" class="butClass" src="'+this.wysiwyg_path+'/vlcod/n_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'&#324;\',\'\')">');        
        document.write('          <img id="msj" alt="sj" title="ś" class="butClass" src="'+this.wysiwyg_path+'/vlcod/s_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'&#347;\',\'\')">');        
        document.write('          <img id="mz" alt="zj" title="zj" class="butClass" src="'+this.wysiwyg_path+'/vlcod/z_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'&#378;\',\'\')">');             
        //document.write('          <img id="mctx" alt="5" title="Alt+5" class="butClass" src="'+this.wysiwyg_path+'/vlcod/t_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'ț\',\'\')">');       
        document.write('          <img id="mtj" alt="tj" title="tj" class="butClass" src="'+this.wysiwyg_path+'/vlcod/tj_malo2.gif" onClick="'+this.instance_name+'.insertMyText(\'ť\',\'\')">');       
        document.write('          <img id="mdj" alt="gj" title="gj" class="butClass" src="'+this.wysiwyg_path+'/vlcod/gj_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'ď\',\'\')">');       
        document.write('          <img id="mp" alt="sh" title="š" class="butClass" src="'+this.wysiwyg_path+'/vlcod/sh_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'ș\',\'\')">');
        document.write('          <img id="mlevi" alt="sh" title="alt+p" class="butClass" src="'+this.wysiwyg_path+'/vlcod/sh_malo.gif" onClick="'+this.instance_name+'.insertMyText(\'ș\',\'\')">');
        document.write('          <img id="map" alt="sh" title="’" class="butClass" src="'+this.wysiwyg_path+'/vlcod/apostrof.gif" onClick="'+this.instance_name+'.insertMyText(\'’\',\'\')">');

    if(this.misc_format_toolbar){
       //  document.write('         <br>');
        document.write('          <img alt="Remove Formatting" title="Remove Formatting" class="butClass" src="'+this.wysiwyg_path+'/images/unformat.gif" onClick="'+this.instance_name+'.doTextFormat(\'removeformat\',\'\')">');
        //document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        document.write('          <img alt="Undo" title="Undo" class="butClass" src="'+this.wysiwyg_path+'/images/undo.gif" onClick="'+this.instance_name+'.doTextFormat(\'undo\',\'\')">');
        document.write('          <img alt="Redo" title="Redo" class="butClass" src="'+this.wysiwyg_path+'/images/redo.gif" onClick="'+this.instance_name+'.doTextFormat(\'redo\',\'\')">');
        document.write('          <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        //document.write('          <img alt="Cut" title="Cut" class="butClass" src="'+this.wysiwyg_path+'/images/cut.png" onClick="'+this.instance_name+'.doTextFormat(\'cut\',\'\')">');
        //document.write('          <img alt="Copy" title="Copy" class="butClass" src="'+this.wysiwyg_path+'/images/copy.png" onClick="'+this.instance_name+'.doTextFormat(\'copy\',\'\')">');
        //document.write('          <img alt="Paste" title="Paste" class="butClass" src="'+this.wysiwyg_path+'/images/paste.png" onClick="'+this.instance_name+'.doTextFormat(\'paste\',\'\')">');
        if(this.misc_format_toolbar=='br'){
            document.write('         <br>');
        }else if(this.misc_format_toolbar_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
        //dugmici
        document.write('         <br>');           
        document.write('          <img alt="prenesirec" title="prenesi rec" class="butClass" src="'+this.wysiwyg_path+'/vlcod/prenesi.gif" onClick="'+this.instance_name+'.Prenesi(\'\')">'); 
        document.write('          <img alt="prenesi+" id="mplus" title="prenesi plus" class="butClass" src="'+this.wysiwyg_path+'/vlcod/prenesi-plus.gif" onClick="'+this.instance_name+'.PrenesiPlus(\'\')">');                
        document.write('          <img alt="mnozina" title="prenesi mnozinu" class="butClass" src="'+this.wysiwyg_path+'/vlcod/mnozina.gif" onClick="'+this.instance_name+'.Mnozina(\'\')">');            
        document.write('          <img alt="akcenat" title="prenesi akcenat" class="butClass" src="'+this.wysiwyg_path+'/vlcod/akcenat.gif" onClick="'+this.instance_name+'.Akcenat(\'\')">');     
        document.write('          <img alt="akcenat" title="potpis zapisivaca" class="butClass" src="'+this.wysiwyg_path+'/vlcod/signat.gif" onClick="'+this.instance_name+'.Signatura(\'\')">');  
        document.write('          <img alt="iuo" title="iuo" class="butClass" src="'+this.wysiwyg_path+'/vlcod/iuo.gif" onClick="'+this.instance_name+'.Iuo(\'\')">');
        document.write('          <img alt="iel" title="iel" class="butClass" src="'+this.wysiwyg_path+'/vlcod/iel.gif" onClick="'+this.instance_name+'.Iel(\'\')">');  
        document.write('          <img alt="pridev" title="pridev" class="butClass" src="'+this.wysiwyg_path+'/vlcod/pridev1.gif" onClick="'+this.instance_name+'.Pridev(\'\')">');   
        document.write('          <img alt="glagol" title="glagol" class="butClass" src="'+this.wysiwyg_path+'/vlcod/glagol1.gif" onClick="'+this.instance_name+'.Glagol(\'\')">'); 
        document.write('          <img alt="imenica" title="imenica" class="butClass" src="'+this.wysiwyg_path+'/vlcod/imenica1.gif" onClick="'+this.instance_name+'.Imenica(\'\')">');
        document.write('          <img alt="varijanta" title="varijanta" class="butClass" src="'+this.wysiwyg_path+'/vlcod/varijanta.gif" onClick="'+this.instance_name+'.Varijanta(\'\')">');   
        document.write('          <img alt="sh" title="’" class="butClass" src="'+this.wysiwyg_path+'/vlcod/vidi.gif" onClick="'+this.instance_name+'.insertMyText(\' ● v. \',\'\')">'); 
        document.write('          <img alt="Ocisti kod" title="ocisti kod" class="butClass" src="'+this.wysiwyg_path+'/vlcod/ocisti.gif" onClick="'+this.instance_name+'.Ocisti(\'\')">');
        document.write('          <img alt="Porec" title="Por" class="butClass" src="'+this.wysiwyg_path+'/vlcod/por.gif" onClick="'+this.instance_name+'.insertMyText(\' [Por.]\',\'\')">'); 
        document.write('         <br>');   
        document.write('          <img alt="i.ž.r." title="i.ž.r." class="butClass" src="'+this.wysiwyg_path+'/vlcod/zz_malo.gif" onClick="'+this.instance_name+'.insertMyText(\' (i. ž.) — **\',\'\')">'); 
        document.write('          <img alt="i.m.r." title="i.m.r." class="butClass" src="'+this.wysiwyg_path+'/vlcod/muski_rod.gif" onClick="'+this.instance_name+'.insertMyText(\' (i. m.) — **\',\'\')">'); 
        document.write('          <img alt="i.s.r." title="i.s.r." class="butClass" src="'+this.wysiwyg_path+'/vlcod/srednji_rod.gif" onClick="'+this.instance_name+'.insertMyText(\' (i. s.) — **\',\'\')">'); 
        document.write('          <img alt="var." title="var" class="butClass" src="'+this.wysiwyg_path+'/vlcod/var.gif" onClick="'+this.instance_name+'.insertMyText(\' ♦ var. ##\',\'\')">'); 
        document.write('          <img alt="dij. var" title="dij. var" class="butClass" src="'+this.wysiwyg_path+'/vlcod/var-dij.gif" onClick="'+this.instance_name+'.insertMyText(\' ♦ dij. var. ##\',\'\')">');  	
        document.write('          <img alt="sin." title="sin." class="butClass" src="'+this.wysiwyg_path+'/vlcod/sin.gif" onClick="'+this.instance_name+'.insertMyText(\' ♦ sin. ##\',\'\')">'); 
        document.write('          <img alt="dij. sin." title="dij. sin." class="butClass" src="'+this.wysiwyg_path+'/vlcod/dsin.gif" onClick="'+this.instance_name+'.insertMyText(\' ♦ dij. sin. ##\',\'\')">'); 		
		document.write('         <br>');          
    
    if(this.font_format_toolbar1){
 
       //gramatika
        document.write('          <select onChange="'+this.instance_name+'.myTextFormat(\'\',this.options[this.selectedIndex].value)">');        
        document.write('           <option value="">- Gramatika -</option>');        
        document.write('           <option value="(br.) — **">Broj</option>');        
        document.write('           <option value="(gl.) — **">Glagol</option>');
        document.write('           <option value="(gl. p.) — **">Glagol prelazni</option>');
		document.write('           <option value="(gl. pom.) — **">Glagol pomoćni</option>');
        document.write('           <option value="(gl. p. ref.) — **">Glagol prelaz. refl.</option>');
        document.write('           <option value="(gl. ref.) — **">Glagol refleksni</option>');
        document.write('           <option value="(gl. n.) — **">Glagol neprelazni</option>');        
        document.write('           <option value="(gl. bezl.) — **">Glagol: bezlični</option>');        
        document.write('           <option value="(gl. nesvrš.) — **">Glagol: nesvršeni vid</option>');                
        document.write('           <option value="(i. ž.) — **">Imenica ženski rod</option>');
        document.write('           <option value="(i. m.) — **">Imenica muški rod</option>');
        document.write('           <option value="(i. s.) — **">Imenica srednji rod</option>');  
        document.write('           <option value="(i. zb.) — **">Imenica zbirna</option>');           
        document.write('           <option value="(predl.) — **">Predlog</option>');  
        document.write('           <option value="(pref.) — **">Prefiks</option>');        
        document.write('           <option value="(prid.) — **">Pridev</option>'); 
        document.write('           <option value="(prid.) (nepr.) — **">Pridev nepromenlj.</option>'); 
        document.write('           <option value="(pril.) — **">Prilog</option>');
        document.write('           <option value="(part.) — **">Rečica</option>');  
        document.write('           <option value="(sint.) — **">Sintagma</option>');  		
        document.write('           <option value="(uzv.) — **">Uzvik</option>');
        document.write('           <option value="(vez.) — **">Veznik</option>');
        document.write('           <option value="(zam.) — **">Zamenica</option>'); 
        document.write('           <option value="(čl.) — **">Član</option>'); 		
        document.write('          </select>');      
       //svojstvo
       document.write('          <select onChange="'+this.instance_name+'.myTextFormat(\'\',this.options[this.selectedIndex].value)">');        
        document.write('           <option value="">- Svojstvo -</option>');              
        document.write('           <option value="(augm.)">Augmentativ</option>');        
        document.write('           <option value="(demin.)">Deminutiv</option>');
        document.write('           <option value="(dosl.)">Doslovce</option>');
        document.write('           <option value="(euf.)">Eufemizam</option>');
        document.write('           <option value="(fam.)">Familijarno</option>');
        document.write('           <option value="(fig.)">Figurativno</option>');
        document.write('           <option value="(hip.)">Hipokoristik</option>');        
        document.write('           <option value="(iron.)">Ironično</option>');        
        document.write('           <option value="(izob.)">Izobičajeno</option>');
        document.write('           <option value="(kom.)">Komentar</option>');                             
        document.write('           <option value="(komp.)">Komparativ</option>');         
        document.write('           <option value="(onom.)">Onomatopeja</option>');               
        document.write('           <option value="(pej.)">Pejorativ (pogr.)</option>');
        document.write('           <option value="(ret.)">Retko u upot.</option>');       
        document.write('           <option value="(srod.)">Srodstvo</option>');        
        document.write('           <option value="(srb.)">Srbska reč</option>');
        document.write('           <option value="(folk.)">U folkloru</option>');
        document.write('           <option value="(vulg.)">Vulgarno</option>');
        document.write('           <option value="(zast.)">Zastarelo</option>');                
        document.write('          </select>');      
       // oblasti
       document.write('          <select onChange="'+this.instance_name+'.myTextFormat(\'\',this.options[this.selectedIndex].value)">');        
        document.write('           <option value="">- Oblasti -</option>');        
        document.write('           <option value="[Bran.]">Braničevci</option>');        
        document.write('           <option value="[Buf.]">Bufani</option>');        
        document.write('           <option value="[Crn.]">Crnorečani</option>');
        document.write('           <option value="[Dun.]">Dunavljani</option>');
        document.write('           <option value="[GPek]">Gornjopečani</option>');        
        document.write('           <option value="[Hom.]">Homoljci</option>');
        document.write('           <option value="[Kmp.]">Kmpenji</option>');                    
        document.write('           <option value="[Mlava]">Mlavljani</option>'); 
        document.write('           <option value="[Mor.]">Moravci-Ćuprijci</option>');               
        document.write('           <option value="[Pad.]">Padurenji</option>');
        document.write('           <option value="[Pom.]">Pomoravci</option>');
        document.write('           <option value="[Por.]">Porečani</option>');
        document.write('           <option value="[Res.]">Resavci</option>');
        document.write('           <option value="[Stig]">Stižani</option>');
        document.write('           <option value="[Tim.]">Timočani</option>');
        document.write('           <option value="[Zvizd]">Zviždani</option>');
        document.write('           <option value="[Rom.]">Vlaški Romi</option>');
        document.write('           <option value="[BBan.]">Banaćani iz Banata</option>');
        document.write('           <option value="[BBuf.]">Banatski Bufani</option>');
        document.write('           <option value="[BArd.]">Banatski Erdeljci</option>');
        document.write('           <option value="[Vid.]">Vidinski Vlasi</option>');       
        document.write('          </select>');
       //umotvorine
       document.write('          <select onChange="'+this.instance_name+'.myTextFormat(\'\',this.options[this.selectedIndex].value)">');        
        document.write('           <option value="">- Umotvorine -</option>');              
        document.write('           <option value="(aneg.)">Anegdota</option>');
        document.write('           <option value="(baj.)">Bajalica</option>');
        document.write('           <option value="(broj.)">Brojalica</option>');                
        document.write('           <option value="(brz.)">Brzalica</option>');        
        document.write('           <option value="(demon.)">Demonizam</option>');
        document.write('           <option value="(izr.)">Izreka</option>');        
        document.write('           <option value="(klet.)">Kletva</option>');
        document.write('           <option value="(leg.)">Legenda</option>');
        document.write('           <option value="(mag.)">Magija</option>');        
        document.write('           <option value="(mitol.)">Mitologija</option>');        
        document.write('           <option value="(opis)">Opis</option>');                    
        document.write('           <option value="(pit.)">Pitalica</option>');         
        document.write('           <option value="(posl.)">Poslovica</option>');                       
        document.write('           <option value="(psov.)">Psovka (pogr.)</option>');
        document.write('           <option value="(stih)">Stih</option>');
        document.write('           <option value="(usp.)">Uspavanka</option>');
        document.write('           <option value="(ver.)">Verovanje</option>');        
        document.write('           <option value="(zag.)">Zagonetka</option>');        
        document.write('           <option value="(zdrav.)">Zdravica</option>');
        document.write('          </select>');      
        
		//
        if(this.font_format_toolbar1_after=='br'){
            document.write('         <br>');
        }else if(this.font_format_toolbar1_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
        document.write('         <br>');
        
        if(this.alignment_toolbar1_after=='br'){
            document.write('         <br>');
        }else if(this.alignment_toolbar1_after=='|'){
        //    document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
//    
    if(this.font_format_toolbar3){
 
        document.write('          <img id="qbold" alt="Bold" title="Bold" class="butClass" src="'+this.wysiwyg_path+'/images/bold.png" onClick="'+this.instance_name+'.doTextFormat(\'bold\',\'\')">');
        document.write('          <img alt="Italic" title="Italic" class="butClass" src="'+this.wysiwyg_path+'/images/italic.png" onClick="'+this.instance_name+'.doTextFormat(\'italic\',\'\')">');
        document.write('          <img alt="Underline" title="Underline" class="butClass" src="'+this.wysiwyg_path+'/images/underline.png" onClick="'+this.instance_name+'.doTextFormat(\'underline\',\'\')">');
        if(this.font_format_toolbar3_after=='br'){
            document.write('         <br>');
        }else if(this.font_format_toolbar3_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
    if(this.font_format_toolbar4){
        document.write('          <img alt="Superscript" title="Superscript" class="butClass" src="'+this.wysiwyg_path+'/images/sup.png" onClick="'+this.instance_name+'.doTextFormat(\'superscript\',\'\')">');
        document.write('          <img alt="Subscript" title="Subscript" class="butClass" src="'+this.wysiwyg_path+'/images/sub.png" onClick="'+this.instance_name+'.doTextFormat(\'subscript\',\'\')">');
        if(this.font_format_toolbar4_after=='br'){
            document.write('         <br>');
        }else if(this.font_format_toolbar4_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
    if(this.alignment_toolbar1){
        document.write('          <img alt="Left" title="Left" class="butClass" src="'+this.wysiwyg_path+'/images/left.png" onClick="'+this.instance_name+'.doTextFormat(\'justifyleft\',\'\')">');
        document.write('          <img alt="Center" title="Center" class="butClass" src="'+this.wysiwyg_path+'/images/center.png" onClick="'+this.instance_name+'.doTextFormat(\'justifycenter\',\'\')">');
        document.write('          <img alt="Right" title="Right" class="butClass" src="'+this.wysiwyg_path+'/images/right.png" onClick="'+this.instance_name+'.doTextFormat(\'justifyright\',\'\')">');
        document.write('          <img alt="Full" title="Full" class="butClass" src="'+this.wysiwyg_path+'/images/full.png" onClick="'+this.instance_name+'.doTextFormat(\'justifyfull\',\'\')">');
        if(this.alignment_toolbar1_after=='br'){
            document.write('         <br>');
        }else if(this.alignment_toolbar1_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
    if(this.alignment_toolbar2){
        document.write('          <img alt="Indent" title="Indent" src="'+this.wysiwyg_path+'/images/indent.png" class=butClass onClick="'+this.instance_name+'.doTextFormat(\'indent\',\'\')">');
        document.write('          <img alt="Outdent" title="Outdent" src="'+this.wysiwyg_path+'/images/outdent.png" class=butClass onClick="'+this.instance_name+'.doTextFormat(\'outdent\',\'\')">');
        if(this.alignment_toolbar2_after=='br'){
            document.write('         <br>');
        }else if(this.alignment_toolbar2_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
    if(this.web_toolbar2){
        document.write('          <img alt="Ordered List" title="Ordered List" class="butClass" src="'+this.wysiwyg_path+'/images/ordlist.png"  onClick="'+this.instance_name+'.doTextFormat(\'insertorderedlist\',\'\')">');
        document.write('          <img alt="Bulleted List" title="Bulleted List" class="butClass" src="'+this.wysiwyg_path+'/images/bullist.png" onClick="'+this.instance_name+'.doTextFormat(\'insertunorderedlist\',\'\')">');
        if(this.web_toolbar2_after=='br'){
            document.write('         <br>');
        }else if(this.web_toolbar2_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
    if(this.web_toolbar3){
        document.write('          <img alt="Horizontal Rule" title="Horizontal Rule" class="butClass" src="'+this.wysiwyg_path+'/images/rule.png" onClick="'+this.instance_name+'.doTextFormat(\'inserthorizontalrule\',\'\')">');
        document.write('          <img alt="Insert Table" title="Insert Table" class="butClass" src="'+this.wysiwyg_path+'/images/table.png" onClick="'+this.instance_name+'.insertTable()">');
        if(this.web_toolbar3_after=='br'){
            document.write('         <br>');
        }else if(this.web_toolbar3_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
    if(this.web_toolbar4){
        //paun odavde iskljucio insert image
        if(this.save_button)
            document.write('          <input type="image" alt="Save" title="Save" class="butClass" src="'+this.wysiwyg_path+'/images/save.png" name="'+this.instance_name+'_save">');
        if(this.web_toolbar4_after=='br'){
            document.write('         <br>');
        }else if(this.web_toolbar4_after=='|'){
            document.write('         <img alt="|" src="'+this.wysiwyg_path+'/images/separator.png">');
        }
    }
       
    document.write('         </div>');
    document.write('        </td>');
    document.write('       </tr>');
    document.write('      </table>');
    //    
    document.write('      <iframe id="'+this.wysiwyg_content+'" style="margin-left: 3px; background-color: white; color: black; width:'+this.frame_width+'px; height:'+this.frame_height+'px;"></iframe>');
    document.write('      <table width="'+this.frame_width+'" border="0" cellspacing="0" cellpadding="0" bgcolor="#dfdfdf">');
    document.write('       <tr>');
    document.write('        <td>');
    document.write('        </td>');
    document.write('        <td align="right">');
    if(this.allow_mode_toggle){
        document.write('         <img alt="Toggle Mode" title="Toggle Mode" class="butClass" src="'+this.wysiwyg_path+'/images/mode.png" onClick="'+this.instance_name+'.toggleMode()">');
    }
    document.write('        </td>');
    document.write('       </tr>');
    document.write('      </table>');
    document.write('     </td>');
    document.write('    </tr>');
    document.write('   </table>');
    document.write('   <br>');
}

function Makroi(evt) 
{
if (evt.altKey && evt.keyCode==65) //ă
    { document.getElementById("ma").click(); }
//if (evt.altKey && evt.keyCode==81) // alt+Q (bilo 66) B = bold 
//if (evt.altKey && evt.keyCode==66) //B bold  
    { document.getElementById("qbold").click();}	
if (evt.altKey && evt.keyCode==83) //ś 
    { document.getElementById("msj").click(); }
if (evt.altKey && evt.keyCode==71) //ḑ, alt+g  
    { document.getElementById("mdz").click();}
//if (evt.altKey && evt.keyCode==0) //ḑ, alt+d, 68 
//    { document.getElementById("mdz").click();}
	
if (evt.altKey && evt.keyCode==73) //î 
    { document.getElementById("mi").click();}
if (evt.altKey && evt.keyCode==78) //ń 
    { document.getElementById("mn").click();}
if (evt.altKey && evt.keyCode==76) //lj 
    { document.getElementById("ml").click();}
if (evt.altKey && evt.keyCode==74) //ĭ 
    { document.getElementById("mj").click();}
if (evt.altKey && evt.keyCode==90) //ź 
    { document.getElementById("mz").click();}
if (evt.altKey && evt.keyCode==80) //ș, kuca se Alt+p, nema kod [  
    { document.getElementById("mt").click();}
//if (evt.altKey && evt.keyCode==53) //ț, kuca se Alt+5   
   // { document.getElementById("mct").click();}
if (evt.altKey && evt.keyCode==109) //— **   
    { document.getElementById("mlin").click();}	
if (evt.altKey && evt.keyCode==48) // nula0 ș, [, ENGL tast  
    { document.getElementById("mlevi").click();}
if (evt.altKey && evt.keyCode==107) //prenesi +  
    { document.getElementById("mplus").click();}
if (evt.altKey && evt.keyCode==81) //al+q
{     
    document.getElementById("boldp").click();
}
//********************************************************************************
//********************************************************************************
}


//**********************************************************************************
//**********************************************************************************
//**********************************************************************************
//**********************************************************************************
//**********************************************************************************
WYSIWYG_Editor.prototype.insertAtCursor = function(myVal) 
{
    //IE support
    // alert ("usao u funkciju");
    document.getElementById("boldp").click();
    var myValue="Nema Kursora";
    document.getElementById("boldp").click();
    var myField = document.getElementById(this.wysiwyg_content).contentWindow;
    myField.focus();
     myField.selectionStart || myField.selectionStart == '0';
    {
       
        
        var startPos = myField.selectionStart;
        var endPos = myField.selectionEnd;
        
        myField.value = myField.value.substring(0, startPos) + "<b>" 
                    +myField.value.substring(startPos, startPos+1)
                      + "</b>"
                    + myField.value.substring(endPos+1, myField.value.length);
    } 
   
        myField.value += myValue;
    
}

//**********************************************************************************
//**********************************************************************************
//**********************************************************************************
//**********************************************************************************
//**********************************************************************************

//this.wysiwyg_hidden=this.instance_name+'_content'; 
WYSIWYG_Editor.prototype.Prenesi = function () 
{
var text = document.obrada.vlaska_rec.value;
this.insertMyText1('<b>'+text+'</b>&nbsp;',''); 
}
//prenos reci za ubacivanje u tekst
WYSIWYG_Editor.prototype.PrenesiPlus = function () 
{
var text = document.obrada.vlaska_rec.value;
this.insertMyText(text,''); 
}

//
WYSIWYG_Editor.prototype.Prenesi_vidi = function () 
{
var text = document.obrada.vlaska_rec.value;
var text1 = text+' [akc. '+text+'] ';
    this.insertMyText(text1,''); 
}

//
WYSIWYG_Editor.prototype.Varijanta = function () 
{
var text = document.obrada.vlaska_rec.value;
var text1 = '<b>'+text+'</b> [akc. '+text+']' + ' gram '+' ● v. <b>'+text+'</b> [Por.] ∞ <b>'+text+'</b>';
    this.insertMyText1(text1,''); 
}

//
WYSIWYG_Editor.prototype.Mnozina = function () 
{
var text = document.obrada.vlaska_rec.value;
var text1 = '(mn. '+text+') ';
    this.insertMyText(text1,''); 
}
//
WYSIWYG_Editor.prototype.Akcenat = function () 
{
var text = document.obrada.vlaska_rec.value;
var text1 = '[akc. '+text+'] ';
    this.insertMyText(text1,''); 
}

//
WYSIWYG_Editor.prototype.Gramatika = function () 
{
var text = document.obrada.gramatika.value;
var text1 = '('+text+') ';
    this.insertMyText(text1,''); 
}
//
WYSIWYG_Editor.prototype.Signatura = function () 
{
var text = document.obrada.signatura.value;
var text1 = 'Zapis: '+text+' ';
    this.insertMyText(text1,''); 
}

//
WYSIWYG_Editor.prototype.Pridev = function () 
{
var text = document.obrada.vlaska_rec.value;
var text2 = text.substr(0,text.length-1) 
var text1 = '<b>'+text+'</b> (<b>'+text+'ă</b>) (mn. <b>'+text2+'ţ</b>, <b>'+text2+'će</b>) [akc. '+text+'] (prid.) ';
this.insertMyText1(text1,''); 
}

//
WYSIWYG_Editor.prototype.Glagol = function () 
{
var text = document.obrada.vlaska_rec.value;
var text2 = text.substr(0,text.length-1) 
var akcent = text.substr(text.length-1,text.length)
var text3 = text2+'<b>'+akcent+'</b>';
var juo = "";
var jel = "";
if (akcent == "î") {
    juo = "ăsk";
	jel = "așće";
}

if (akcent == "i") {
    juo = "ĭesk";
	jel = "ĭașće";
}

var text1 = '<b>'+text+'</b> (ĭuo <b>'+ text2 + juo+'</b>, ĭel <b>'+text2 + jel+'</b>) [akc. '+text3+'] ';
    this.insertMyText1(text1,''); 
}

//
WYSIWYG_Editor.prototype.Imenica = function () 
{
var text = document.obrada.vlaska_rec.value;
var text2 = text.substr(0,text.length-1) 
var text1 = '<b>'+text+'</b> (mn. <b>'+ text2 + '</b>) [akc. '+text+'] ';
    this.insertMyText1(text1,''); 
}

//
WYSIWYG_Editor.prototype.Iuo = function () 
{
//var text = document.obrada.signatura.value;
var text1 = 'ĭuo ';
    this.insertMyText(text1,''); 
}
//
WYSIWYG_Editor.prototype.Iel = function () 
{
//var text = document.obrada.signatura.value;
var text1 = ' ĭel ';
    this.insertMyText(text1,''); 
}
//
WYSIWYG_Editor.prototype.myTextFormat = function (command, vrednost)
{
   var text1 = vrednost;
   this.insertMyText(text1,''); 
}

WYSIWYG_Editor.prototype.Ocisti = function () 
{
var text = document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML
var text1 = text.replace(/&nbsp;/g,' '); 
var text1 = text.replace(/\<div\>/g,' '); 
var text1 = text.replace(/\<\/div\>/g,' '); 
    this.insertMyText1(text1,''); 
}

WYSIWYG_Editor.prototype.Italikuj = function () 
{
var text = document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML

var text1 = text.replace(/&nbsp;/g,' '); 
var text1 = text1.replace(/\<sup\>1\<\/sup\>/g,'indexunu');
var text1 = text1.replace(/\<sup\>2\<\/sup\>/g,'indexdoi');
var text1 = text1.replace(/\<br\>/g,''); 

//var text1 = text1.replace(/\<b\>\<b\>/g,''); 
//var text1 = text1.replace(/\<\/b/>\<\/b/>/g,''); 

var text1 = text1.replace(/ \*/g,' <i>');
var text1 = text1.replace(/\* /g,'</i> ');
var text1 = text1.replace(/ \<\/i\>/g,'</i> '); 
var text1 = text1.replace(/∞ #/g,'∞ <b>');
//var text1 = text1.replace(/ #/g,' <b>');
var text1 = text1.replace(/%/g,'<b>');
var text1 = text1.replace(/#/g,'</b>'); 
var text1 = text1.replace(/1./g,'<b>1.</b>');
var text1 = text1.replace(/2./g,'<b>2.</b>'); 
var text1 = text1.replace(/3./g,'<b>3.</b>');
var text1 = text1.replace(/4./g,'<b>3.</b>');
var text1 = text1.replace(/5./g,'<b>3.</b>');
var text1 = text1.replace(/  /g,' '); 
var text1 = text1.replace(/indexunu/g, '<sup>1</sup>');
var text1 = text1.replace(/indexdoi/g, '<sup>2</sup>');
//var text1 = text1.replace(/\*\<br\>\<\/i\>/g,'</i> '); 
    this.insertMyText1(text1,''); 
}

/*******
// Paun Es Durlic 25.08.2011 u 17:30
// umetanje karaktera u tekst (text, textarea)
// doradjena uz pomoc Dusana Vasiljevica sa foruma
// http://www.elitesecurity.org/t435701-0#2937892
// 29. VIII 2011
// uspeo sam da esim 10.01.2021
// ostaopoblem daa se iygubio kurosor
*********/
WYSIWYG_Editor.prototype.insertMyTextBOLD = function (text, textarea) {

    var znak = '%'; //text;   
    var znak2 = '#';  
    //var textarea = document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML;
    //alert("text "+text)   
     textarea=document.getElementById(this.wysiwyg_content).contentWindow;
	 var sel = textarea.getSelection();      
     var range = sel.getRangeAt(0);
     sel.removeAllRanges();                  
     range.deleteContents();                 
     var container = range.startContainer;      
     var pos = range.startOffset;    
     if (container == "[object Text]"){
          container.insertData(pos, znak);
          container.insertData(pos+2, znak2);
          
        var text = document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML;       
		var text1 = text.replace(/%/g,'<b>');
		var text1 = text1.replace(/#/g,'</b>'); 
        this.insertMyText1(text1,'');
        object.style.cursor= "text";
        }
        else {
          var textnod = document.createTextNode(znak);
          range.insertNode(textnod);
        }
         
     range=document.createRange();
	 /* -1 vraca kursor za jendo mesto unazad */
     range.setEnd(container, pos+znak.length-1);
	 range.setStart(container, pos+znak.length-1);
     sel.removeAllRanges();
     sel.addRange(range);
     document.getElementById(this.wysiwyg_content).contentWindow.focus();
     document.getElementById(this.wysiwyg_content).focus();   
 
}

//rešeno 9. X 2017
//upisuje tagovanu rec u skriven tekst editora
WYSIWYG_Editor.prototype.insertMyText1 = function (text, textarea) {

    var znak = text;       
    document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML = znak;      
    document.getElementById(this.wysiwyg_content).focus();
   
}


/*******
// Paun Es Durlic 25.08.2011 u 17:30
// umetanje karaktera u tekst (text, textarea)
// doradjena uz pomoc Dusana Vasiljevica sa foruma
// http://www.elitesecurity.org/t435701-0#2937892
// 29. VIII 2011
*******/
WYSIWYG_Editor.prototype.insertMyText = function (text, textarea) {

    var znak = text;   
    if (this.isMSIE())
    {
    document.getElementById(this.wysiwyg_content).contentWindow.focus();      
    var textarea=document.getElementById(this.wysiwyg_content).contentWindow.document.selection.createRange();
    textarea.pasteHTML(znak);
    document.getElementById(this.wysiwyg_content).contentWindow.focus();
 } else {        
     textarea=document.getElementById(this.wysiwyg_content).contentWindow;
     var sel = textarea.getSelection();      // get current selection
     var range = sel.getRangeAt(0);
     sel.removeAllRanges();                  // deselect everything //poništite sve
     range.deleteContents();                 // remove content of current selection from document                                                                                      
     var container = range.startContainer;   // get location of current selection -    
     var pos = range.startOffset;    

     if (container == "[object Text]"){
          container.insertData(pos, znak);
        }
        else {
          var textnod = document.createTextNode(znak);
          range.insertNode(textnod);
        }
         
     range=document.createRange();
     range.setEnd(container, pos+znak.length);
	 range.setStart(container, pos+znak.length);
     sel.removeAllRanges();
     sel.addRange(range);

     document.getElementById(this.wysiwyg_content).contentWindow.focus();
     
    } 
}
/* samo za - ** i ## radi vracanja kursora za jedno msto nazad posle unose */
WYSIWYG_Editor.prototype.insertMyTextLIN = function (text, textarea) {

    var znak = text;   
//    if (this.isMSIE())
//    {
    //document.getElementById(this.wysiwyg_content).contentWindow.focus();      
    //var textarea=document.getElementById(this.wysiwyg_content).contentWindow.document.selection.createRange();
    //textarea.pasteHTML(znak);
    //document.getElementById(this.wysiwyg_content).contentWindow.focus();
 //   } else { 
	
     textarea=document.getElementById(this.wysiwyg_content).contentWindow;
	 var sel = textarea.getSelection();      // get current selection
     var range = sel.getRangeAt(0);
     sel.removeAllRanges();                  // deselect everything //poništite sve
     range.deleteContents();                 // remove content of current selection from document                                                                                      
     var container = range.startContainer;   // get location of current selection -    
     var pos = range.startOffset;    

     if (container == "[object Text]"){
          container.insertData(pos, znak);
        }
        else {
          var textnod = document.createTextNode(znak);
          range.insertNode(textnod);
        }
         
     range=document.createRange();
	 /* -1 vraca kursor za jendo mesto unazad */
     range.setEnd(container, pos+znak.length-1);
	 range.setStart(container, pos+znak.length-1);
     sel.removeAllRanges();
     sel.addRange(range);
     document.getElementById(this.wysiwyg_content).contentWindow.focus();
     
   // } 
}
/**
*   WYSIWYG_Editor::doTextFormat
*   Apply a text formatting command to the selected text in the editor (or starting at the current cursor position)
*   @param  command string  Which of the editor/browser text formatting commands to apply
**/
WYSIWYG_Editor.prototype.doTextFormat = function (command, optn, evnt)
     {
     document.getElementById(this.wysiwyg_content).contentWindow.document.execCommand(command, false, optn);
     document.getElementById(this.wysiwyg_content).contentWindow.focus();
}

/**
*   WYSIWYG_Editor::_load_content
*   Puts the passed content into the editor or textarea (Use this one *after* displaying the editor.)
*   @param  content string  The string containing the properly-formatted HTML source to use
*/
WYSIWYG_Editor.prototype._load_content = function (){
    document.getElementById(this.wysiwyg_hidden).value=this.content;
}

/**
*   WYSIWYG_Editor::toggleMode
*   Toggles between design view and source view in the IFRAME element
**/
WYSIWYG_Editor.prototype.toggleMode = function (){
    // change the display styles
    if(this.viewMode == 2){
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.fontFamily = 'Cambria';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.fontSize = '16px';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.color = '';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.fontWeight = '';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.backgroundColor = '';
        document.getElementById(this.instance_name+'_toolbars').style.visibility='visible';
    }else{
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.fontFamily = 'Cambria';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.fontSize = '16px';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.color = '#000';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.backgroundColor = '#fff';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.style.fontWeight = 'normal';
        document.getElementById(this.instance_name+'_toolbars').style.visibility='hidden';
    }
    // do the content swapping
    if(this.isMSIE()){
        this._toggle_mode_ie();
    }else{
        this._toggle_mode_gecko();
    }
}

/**
*   WYSIWYG_Editor::_toggle_mode_ie
*   Toggles between design view and source view in the IFRAME element for MSIE
**/
WYSIWYG_Editor.prototype._toggle_mode_ie = function (){
    if(this.viewMode == 2){
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML = document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerText;
        document.getElementById(this.wysiwyg_content).contentWindow.focus();
        this.viewMode = 1; // WYSIWYG
    }else{
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerText = document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML;
        document.getElementById(this.wysiwyg_content).contentWindow.focus();
        this.viewMode = 2; // Code
    }
}

/**
*   WYSIWYG_Editor::_toggle_mode_gecko
*   Toggles between design view and source view in the IFRAME element for Gecko browsers
**/
WYSIWYG_Editor.prototype._toggle_mode_gecko = function (){
   
    if(this.viewMode == 2){
        var html = document.getElementById(this.wysiwyg_content).contentWindow.document.body.ownerDocument.createRange();
        html.selectNodeContents(document.getElementById(this.wysiwyg_content).contentWindow.document.body);
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML = html.toString();
        document.getElementById(this.wysiwyg_content).contentWindow.focus();
        this.viewMode = 1; // WYSIWYG
    }else{
        var html = document.createTextNode(document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML);
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.innerHTML = '';
        document.getElementById(this.wysiwyg_content).contentWindow.document.body.appendChild(html);
        document.getElementById(this.wysiwyg_content).contentWindow.focus();
        this.viewMode = 2; // Code
    }
}

/**
*   WYSIWYG_Editor::_get_offset_left
*   Used to define position of pop-up pallete window in Gecko browsers
**/
WYSIWYG_Editor.prototype._get_offset_left = function (elm){
    var mOffsetLeft=elm.offsetLeft;
    var mOffsetParent=elm.offsetParent;
    while(mOffsetParent){
        mOffsetLeft += mOffsetParent.offsetLeft;
        mOffsetParent=mOffsetParent.offsetParent;
    }
    return mOffsetLeft;
}

/**
*   WYSIWYG_Editor::_get_offset_top
*   Used to define position of pop-up pallete window in Gecko browsers
**/
WYSIWYG_Editor.prototype._get_offset_top = function (elm){
    var mOffsetTop=elm.offsetTop;
    var mOffsetParent=elm.offsetParent;
    while(mOffsetParent){
        mOffsetTop += mOffsetParent.offsetTop;
        mOffsetParent=mOffsetParent.offsetParent;
    }
    return mOffsetTop;
}

/**
*   WYSIWYG_Editor::insertTable
*   Used for inserting a table into the IFRAME content window
**/
WYSIWYG_Editor.prototype.insertTable = function (){
    colstext = prompt('Enter the number of columns per row.');
    rowstext = prompt('Enter the number of rows to create.');
    rows = parseInt(rowstext,'0');
    cols = parseInt(colstext,'0');
    
    if(this.isMSIE()){
        return this._insert_table_ie(cols,rows);
    }else{
        return this._insert_table_gecko(cols,rows);
    }
}

/**
*   WYSIWYG_Editor::_insert_table_ie
*   This is the browser engine-specific code for inserting a table for MSIE browsers.
*   @param  cols    The number of columns to create
*   @param  rows    The number of rows to create
**/
WYSIWYG_Editor.prototype._insert_table_ie = function (cols, rows){
    document.getElementById(this.wysiwyg_content).contentWindow.focus();

    //get current selected range
    var cursor=document.getElementById(this.wysiwyg_content).contentWindow.document.selection.createRange();
    if((rows > 0) && (cols > 0)){
        var tableHTML = '<table border="'+this.table_border+'" cellpadding="'+this.table_cell_padding+'" cellspacing="'+this.table_cell_spacing+'">';
        while(rows>0){
            rows--;
            var rowCols = cols;
            tableHTML = tableHTML + '<tr>';
            while(parseInt(rowCols)>0){
                rowCols--;
                tableHTML=tableHTML+'<td>&nbsp;</td>';
            }
            tableHTML = tableHTML + '</tr>';
        }
        tableHTML = tableHTML + '</table>';
        cursor.pasteHTML(tableHTML);
        document.getElementById(this.wysiwyg_content).contentWindow.focus();
    }
    return true;
}

/**
*   WYSIWYG_Editor::_insert_table_gecko
*   This is the browser engine-specific code for inserting a table for Gecko browsers.
*   @param  cols    The number of columns to create
*   @param  rows    The number of rows to create
**/
WYSIWYG_Editor.prototype._insert_table_gecko = function (cols, rows){
    contentWin=document.getElementById(this.wysiwyg_content).contentWindow;
   
    if((rows > 0) && (cols > 0)){
        table=contentWin.document.createElement('table');
        table.setAttribute('border', this.table_border);
        table.setAttribute('cellpadding', this.table_cell_padding);
        table.setAttribute('cellspacing', this.table_cell_spacing);
        tbody=contentWin.document.createElement('tbody');
        for(i=0;i<rows;i++){
            tr=contentWin.document.createElement('tr');
            for(j=0;j<cols;j++){
                td=contentWin.document.createElement('td');
                br=contentWin.document.createElement('br');
                td.appendChild(br);
                tr.appendChild(td);
            }
            tbody.appendChild(tr);
        }
        table.appendChild(tbody);
        this._insert_element_gecko(contentWin, table);
    }
    return true;
}

/**
*   WYSIWYG_Editor::_insert_element_gecko
*   Used by Gecko browsers to insert elements into the document for the insertTable method
*   @param  win The window object to insert the element into
*   @param  elem    The element to insert into the content window
**/
WYSIWYG_Editor.prototype._insert_element_gecko = function (win, elem){
    var sel = win.getSelection();           // get current selection
    var range = sel.getRangeAt(0);          // get the first range of the selection (there's almost always only one range)
    sel.removeAllRanges();                  // deselect everything
    range.deleteContents();                 // remove content of current selection from document
    var container = range.startContainer;   // get location of current selection
    var pos = range.startOffset;
    range=document.createRange();           // make a new range for the new selection

    if (container.nodeType==3 && elem.nodeType==3) {
        // if we insert text in a textnode, do optimized insertion
        container.insertData(pos, elem.nodeValue);

        // put cursor after inserted text
        range.setEnd(container, pos+elem.length);
        range.setStart(container, pos+elem.length);
    }else{
        var afterNode;
        if (container.nodeType==3) {
          // when inserting into a textnode we create 2 new textnodes and put the elem in between
          var textNode = container;
          container = textNode.parentNode;
          var text = textNode.nodeValue;

          var textBefore = text.substr(0,pos);  // text before the split
          var textAfter = text.substr(pos);     // text after the split

          var beforeNode = document.createTextNode(textBefore);
          var afterNode = document.createTextNode(textAfter);

          // insert the 3 new nodes before the old one
          container.insertBefore(afterNode, textNode);
          container.insertBefore(elem, afterNode);
          container.insertBefore(beforeNode, elem);

          // remove the old node
          container.removeChild(textNode);
        }else{
          // else simply insert the node
          afterNode = container.childNodes[pos];
          container.insertBefore(elem, afterNode);
        }
    }
}

/**
*   WYSIWYG_Editor::isSupported
*   Checks that the browser supports this programming by writing an invisible IFRAME and testing its properties
*/
WYSIWYG_Editor.prototype.isSupported = function () {
    // This is to get rid of the browser UA check that was previously implemented for this class.
    // should be called from somewhere in the body of the document for best results
    document.write('<iframe id="WYSIWYG_Editor_Testing_Browser_Features" style="display: none; visibility: hidden;"></iframe>');
    test = typeof(document.getElementById('WYSIWYG_Editor_Testing_Browser_Features').contentWindow);
    if(test == 'object'){
        return true;
    }else{
        return false;
    }
    return this.supported;
}

/**
*   WYSIWYG_Editor::isMSIE
*   Checks if browser is MSIE by testing the document.all property that is only supported by MSIE and AOL
*/
WYSIWYG_Editor.prototype.isMSIE = function (){
    if(typeof(document.all)=='object'){
        return true;
    }else{
        return false;
    }
}

/**
*   WYSIWYG_Editor::insertImage
*
*   Brings a pop-up window for the user to choose an image from to insert into the contents
*   This is really only part of my custom CMS, but I left it here for reference if other people
*   want to use a similar method.
**/
WYSIWYG_Editor.prototype.insertImage = function (){
    this.imagePopUp=window.open(this.site_path+'/_include/back_end/image_dialog.php?page_title='+this.page_title,'','width=620,height=500,resizable=1,scrollbars=yes');

    //get current selected range
    var sel=document.getElementById(this.wysiwyg_content).contentWindow.document.selection;
    if(sel!=null){
        rng=sel.createRange();
    }
}

/********
* ende
********/
